"""Top-level package for pandect."""

__author__ = """Brendan Strejcek"""
__email__ = 'brendan@datagazing.com'
__version__ = '0.3.0'

from .pandect import load, save, pandect, sav2dta # noqa
